#
# spec file for package python-Coherence
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Coherence
Version:        0.6.6.2
Release:        13.3
Url:            http://coherence-project.org
Summary:        Coherence - DLNA/UPnP framework for the digital living
License:        MIT
Group:          Development/Languages/Python
Source:         http://coherence.beebits.net/download/Coherence-0.6.6.2.tar.gz
Patch0:         coherence-getPage.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-devel
# We drop the internal version in coherence tree
BuildRequires:  python-Louie
BuildRequires:  python-Twisted
BuildRequires:  python-setuptools
# Requires pkg_resources
Requires:       python-setuptools
# As we drop the internal version, we need to require our own package.
Requires:       python-Axiom
Requires:       python-Epsilon
Requires:       python-Louie
Requires:       python-Twisted
Requires:       python-tagpy
Recommends:     python-gstreamer-0_10
# Youtube MediaServer
Recommends:     python-gdata
# Flickr MediaServer
Suggests:       python-mechanize
# For directory ownership:
BuildRequires:  dbus-1
Requires:       dbus-1
Provides:       python-coherence = %{version}
#TODO: Change back to '<' after next version update:
Obsoletes:      python-coherence <= %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Coherence is a framework written in Python, providing a variety of UPnP
MediaServer and UPnP MediaRenderer implementations for instant use.

It includes an UPnP ControlPoint, which is accessible via D-Bus too.

Furthermore it enables your application to participate in
digital living networks, at the moment primarily the DLNA/UPnP universe.
Its objective and demand is to relieve your application from all the
membership/the UPnP related tasks as much as possible.

%prep
%setup -q -n Coherence-%{version}
%patch0 -p1
# We have python-louie available. Let's not carry the same package more than once
find coherence -type f -exec sed -i 's/coherence.extern.louie as louie/louie/' {} \;
rm coherence/extern/louie.py

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# Install the D-Bus service file
mkdir -p %{buildroot}/%{_datadir}/dbus-1/services
cp -a misc/org.Coherence.service %{buildroot}/%{_datadir}/dbus-1/services/

%files
%defattr(-,root,root,-)
%doc ChangeLog LICENCE NEWS README
%{_bindir}/*
%{_datadir}/dbus-1/services/*.service
%{python_sitelib}/*
# Not really useful here
%exclude %{_bindir}/applet-coherence
%exclude %{python_sitelib}/misc

%changelog
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Jul  1 2012 dimstar@opensuse.org
- Add coherence-getPage.patch: Fix execution with Twisted >= 11.0
- Add python-Axiom, python-Epsilon and python-tagpy Requires
  (bnc#741999).
* Fri Dec  9 2011 saschpe@suse.de
- Change package name to python-Coherence (upstream name)
- Buildrequire python-distribute (instead of setuptools)
- BuildRequire python-Louie (instead of louie)
- Fix SLE-11 build
* Tue Sep 13 2011 vuntz@opensuse.org
- Change python-twisted BuildRequires and Requires to
  python-Twisted, after the package renaming in Factory.
* Mon May 23 2011 dimstar@opensuse.org
- Drop internal louie and Require python-louie instead.
* Tue Jan  5 2010 vuntz@opensuse.org
- Update to version 0.6.6.2:
  + fixing the setup configuration to compensate for the gone
    'auto-include-all-files-under-version-control' setuptools
    feature
  + generic 'genre' handling in DIDLLite
  + fix for broken .face-icon handling in the Rhythmbox plugin
- Drop python-coherence-org.Coherence.service: the file is back in
  the tarball.
* Thu Dec 24 2009 vuntz@opensuse.org
- Update to version 0.6.6.1:
  + fixing the broken tarball of the 0.6.6 release and adding a
    missing import that made some backends unfeasible
- changes from version 0.6.6:
  + new MediaServer backends that allow access to
  - Banshee - exports audio and video files from Banshees media
    db
  - FeedStore - a MediaServer serving generic RSS feeds
  - Playlist - exposes the list of video/audio streams from a m3u
    playlist (e.g. web TV listings published by french ISPs such
    as Free, SFR...)
  - YAMJ - serves the movie/TV series data files and metadata
    from a given YAMJ (Yet Another Movie Jukebox) library
  + updates on Mirabeau - our "UPnP over XMPP" bridge
  + simplifications in the D-Bus API
  + a first implementation of an JSON/REST API
  + advancements of the GStreamer MediaRenderer, supporting now
    GStreamers playbin2
  + upgrade of the DVB-Daemon MediaServer
  + refinements in the transcoding section, having now the choice
    to use GStreamer pipelines or external processes like mencoder
  + more 'compatibility' improvements for different devices (e.g.
    Samsung TVs or Apache Felix)
  + and - as every time - the usual bugfixes and enhancements
- Add python-twisted BuildRequires.
- Ship org.Coherence.service as a source file, since it's missing
  from the tarball.
- Make package noarch.
* Wed Oct  7 2009 vuntz@opensuse.org
- Change python-devel BuildRequires to python-setuptools
  BuildRequires: else, we're missing some files in the packages.
- Add Requires on python-setuptools too, since pkg_resources is
  needed.
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Sat Jun 13 2009 vuntz@novell.com
- Initial package.
